Developer Information
=====================

The following information may be useful for those wishing to extend LinchPin.

.. toctree::
   :maxdepth: 1

   libdocs
   writing_provider

.. include:: includes/footer.rst
